@@ -2,7 +2,6 @@ from .dashboard import Dashboard
 from .documents import Documents
 from .return_manager import ReturnManager
 from .files_pending import FilesPending
+from .tax_return import TaxReturn
 
-__all__ = [
-	"Dashboard", "Documents", "ReturnManager", "FilesPending"
-]
+__all__ = ["Dashboard", "Documents", "ReturnManager", "FilesPending", "TaxReturn"]
