@@ -44,7 +44,7 @@ class Documents(CchDialog):
                     ("Files" in children.legacy_properties()["Name"])
                     or ("File" in children.legacy_properties()["Name"])
                 ):
-                    files_number = re.sub(r"File|Files", "", children.legacy_properties()["Name"]).strip()
+                    files_number = re.sub(r"[File|Files]", "", children.legacy_properties()["Name"]).strip()
 
             if found_row:
                 break
